@@ -18,97 +18,7 @@ require_once 'libraries/structure.lib.php';
 
 // Add/Remove favorite tables using Ajax request.
 if ($GLOBALS['is_ajax_request'] && ! empty($_REQUEST['favorite_table'])) {
-    $fav_instance = PMA_RecentFavoriteTable::getInstance('favorite');
-    $favorite_tables = json_decode($_REQUEST['favorite_tables'], true);
-    // Required to keep each user's preferences seperate.
-    $user = sha1($GLOBALS['cfg']['Server']['user']);
-
-    // Request for Synchronization of favorite tables.
-    if (isset($_REQUEST['sync_favorite_tables'])) {
-
-        $fav_instance_tables = $fav_instance->getTables();
-
-        if (empty($fav_instance_tables)
-            && isset($favorite_tables[$user])
-        ) {
-            foreach ($favorite_tables[$user] as $key => $value) {
-                $fav_instance->add($value['db'], $value['table']);
-            }
-        }
-        $favorite_tables[$user] = $fav_instance->getTables();
-
-        $ajax_response = PMA_Response::getInstance();
-        $ajax_response->addJSON(
-            'favorite_tables',
-            json_encode($favorite_tables)
-        );
-        $ajax_response->addJSON(
-            'list',
-            $fav_instance->getHtmlList()
-        );
-        $server_id = $GLOBALS['server'];
-        // Set flag when localStorage and pmadb(if present) are in sync.
-        $_SESSION['tmpval']['favorites_synced'][$server_id] = true;
-        exit;
-    }
-    global $db;
-    $changes = true;
-    $msg = '';
-    $titles = PMA_Util::buildActionTitles();
-    $favorite_table = $_REQUEST['favorite_table'];
-    $already_favorite = PMA_checkFavoriteTable($db, $favorite_table);
-
-    if (isset($_REQUEST['remove_favorite'])) {
-        if ($already_favorite) {
-            // If already in favorite list, remove it.
-            $fav_instance->remove($db, $favorite_table);
-        }
-    } elseif (isset($_REQUEST['add_favorite'])) {
-        if (!$already_favorite) {
-            if (count($fav_instance->getTables()) == $GLOBALS['cfg']['NumFavoriteTables']) {
-                $changes = false;
-                $msg = '<div class="error"><img src="themes/dot.gif" '
-                    . 'title="" alt="" class="icon ic_s_error" />'
-                    . __("Favorite List is full!")
-                    . '</div>';
-            } else {
-                // Otherwise add to favorite list.
-                $fav_instance->add($db, $favorite_table);
-            }
-        }
-    }
-
-    $favorite_tables[$user] = $fav_instance->getTables();
-    $ajax_response = PMA_Response::getInstance();
-    $ajax_response->addJSON(
-        'changes',
-        $changes
-    );
-    if ($changes) {
-        $ajax_response->addJSON(
-            'user',
-            $user
-        );
-        $ajax_response->addJSON(
-            'favorite_tables',
-            json_encode($favorite_tables)
-        );
-        $ajax_response->addJSON(
-            'list',
-            $fav_instance->getHtmlList()
-        );
-        $ajax_response->addJSON(
-            'anchor',
-            PMA_getHtmlForFavoriteAnchor(
-                $db, $favorite_table, $titles
-            )
-        );
-    } else {
-        $ajax_response->addJSON(
-            'message',
-            $msg
-        );
-    }
+    PMA_addRemoveFavoriteTables($db);
     exit;
 }
 
@@ -124,7 +34,7 @@ if ((!empty($_POST['submit_mult']) && isset($_POST['selected_tbl']))
     || isset($_POST['mult_btn'])
 ) {
     $action = 'db_structure.php';
-    $err_url = 'db_structure.php?' . PMA_URL_getCommon($db);
+    $err_url = 'db_structure.php' . PMA_URL_getCommon(array('db' => $db));
 
     // see bug #2794840; in this case, code path is:
     // db_structure.php -> libraries/mult_submits.inc.php -> sql.php
@@ -145,10 +55,19 @@ $url_query .= '&amp;goto=db_structure.php';
 $sub_part = '_structure';
 require 'libraries/db_info.inc.php';
 
+// If there is an Ajax request for real row count of a table.
+if ($GLOBALS['is_ajax_request']
+    && isset($_REQUEST['real_row_count'])
+    && $_REQUEST['real_row_count'] == true
+) {
+    PMA_handleRealRowCountRequest();
+    exit;
+}
+
 if (!PMA_DRIZZLE) {
     include_once 'libraries/replication.inc.php';
 } else {
-    $server_slave_status = false;
+    $GLOBALS['replication_info']['slave']['status'] = false;
 }
 
 require_once 'libraries/bookmark.lib.php';
@@ -162,16 +81,9 @@ $titles = PMA_Util::buildActionTitles();
 
 if ($num_tables == 0) {
     $response->addHTML(
-        '<p>' . __('No tables found in database.') . '</p>' . "\n"
+        PMA_message::notice(__('No tables found in database.'))
     );
-    if (empty($db_is_system_schema)) {
-        ob_start();
-        include 'libraries/display_create_table.lib.php';
-        $content = ob_get_contents();
-        ob_end_clean();
-        $response->addHTML($content);
-        unset($content);
-    } // end if (Create Table dialog)
+    PMA_possiblyShowCreateTableDialog($db, $db_is_system_schema, $response);
     exit;
 }
 
@@ -211,7 +123,9 @@ $response->addHTML(
 $response->addHTML(PMA_URL_getHiddenInputs($db));
 
 $response->addHTML(
-    PMA_tableHeader($db_is_system_schema, $server_slave_status)
+    PMA_tableHeader(
+        $db_is_system_schema, $GLOBALS['replication_info']['slave']['status']
+    )
 );
 
 $i = $sum_entries = 0;
@@ -228,7 +142,6 @@ $overhead_size  = (double) 0;
 
 $hidden_fields = array();
 $odd_row       = true;
-$sum_row_count_pre = '';
 // Instance of PMA_RecentFavoriteTable class.
 $fav_instance = PMA_RecentFavoriteTable::getInstance('favorite');
 foreach ($tables as $keyname => $current_table) {
@@ -266,9 +179,9 @@ foreach ($tables as $keyname => $current_table) {
 
     if ($is_show_stats) {
         if ($formatted_overhead != '') {
-            $overhead = '<a href="tbl_structure.php?'
+            $overhead = '<a href="tbl_structure.php'
                 . $tbl_url_query . '#showusage">'
-                . '<span>' . $formatted_overhead . '</span>'
+                . '<span>' . $formatted_overhead . '</span>&nbsp;'
                 . '<span class="unit">' . $overhead_unit . '</span>'
                 . '</a>' . "\n";
             $overhead_check .=
@@ -344,11 +257,13 @@ foreach ($tables as $keyname => $current_table) {
             '</tr></tbody></table>'
         );
 
-        $response->addHTML(PMA_tableHeader(false, $server_slave_status));
+        $response->addHTML(
+            PMA_tableHeader(false, $GLOBALS['replication_info']['slave']['status'])
+        );
     }
 
     list($do, $ignored) = PMA_getServerSlaveStatus(
-        $server_slave_status, $truename
+        $GLOBALS['replication_info']['slave']['status'], $truename
     );
     // Handle favorite table list. ----START----
     $already_favorite = PMA_checkFavoriteTable($db, $current_table['TABLE_NAME']);
@@ -369,9 +284,10 @@ foreach ($tables as $keyname => $current_table) {
         }
     } // Handle favorite table list. ----ENDS----
 
-    list($html_output, $odd_row) = PMA_getHtmlForStructureTableRow(
+    list($html_output, $odd_row, $approx_rows) = PMA_getHtmlForStructureTableRow(
         $i, $odd_row, $table_is_view, $current_table,
-        $browse_table_label, $tracking_icon, $server_slave_status,
+        $browse_table_label, $tracking_icon,
+        $GLOBALS['replication_info']['slave']['status'],
         $browse_table, $tbl_url_query, $search_table, $db_is_system_schema,
         $titles, $empty_table, $drop_query, $drop_message, $collation,
         $formatted_size, $unit, $overhead,
@@ -388,9 +304,10 @@ foreach ($tables as $keyname => $current_table) {
 $response->addHTML('</tbody>');
 $response->addHTML(
     PMA_getHtmlBodyForTableSummary(
-        $num_tables, $server_slave_status, $db_is_system_schema, $sum_entries,
-        $db_collation, $is_show_stats, $sum_size, $overhead_size, $create_time_all,
-        $update_time_all, $check_time_all, $sum_row_count_pre
+        $num_tables, $GLOBALS['replication_info']['slave']['status'],
+        $db_is_system_schema, $sum_entries, $db_collation, $is_show_stats, $sum_size,
+        $overhead_size, $create_time_all, $update_time_all, $check_time_all,
+        isset($approx_rows) ? $approx_rows : false
     )
 );
 $response->addHTML('</table>');
@@ -423,12 +340,6 @@ $response->addHTML(
     . PMA_getHtmlForDataDictionaryLink($url_query)
 );
 
-if (empty($db_is_system_schema)) {
-    ob_start();
-    include 'libraries/display_create_table.lib.php';
-    $content = ob_get_contents();
-    ob_end_clean();
-    $response->addHTML($content);
-} // end if (Create Table dialog)
+PMA_possiblyShowCreateTableDialog($db, $db_is_system_schema, $response);
 
 ?>
