@@ -19,7 +19,7 @@ class PMA_Types
     /**
      * Returns list of unary operators.
      *
-     * @return array
+     * @return string[]
      */
     public function getUnaryOperators()
     {
@@ -46,7 +46,7 @@ class PMA_Types
     /**
      * Returns list of operators checking for NULL.
      *
-     * @return array
+     * @return string[]
      */
     public function getNullOperators()
     {
@@ -59,7 +59,7 @@ class PMA_Types
     /**
      * ENUM search operators
      *
-     * @return array
+     * @return string[]
      */
     public function getEnumOperators()
     {
@@ -72,7 +72,7 @@ class PMA_Types
     /**
      * TEXT search operators
      *
-     * @return array
+     * @return string[]
      */
     public function getTextOperators()
     {
@@ -97,7 +97,7 @@ class PMA_Types
     /**
      * Number search operators
      *
-     * @return array
+     * @return string[]
      */
     public function getNumberOperators()
     {
@@ -124,7 +124,7 @@ class PMA_Types
      * @param string  $type Type of field
      * @param boolean $null Whether field can be NULL
      *
-     * @return array
+     * @return string[]
      */
     public function getTypeOperators($type, $null)
     {
@@ -205,7 +205,7 @@ class PMA_Types
      *
      * @param string $class The class to get function list.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getFunctionsClass($class)
@@ -218,7 +218,7 @@ class PMA_Types
      *
      * @param string $type The data type to get function list.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getFunctions($type)
@@ -230,7 +230,7 @@ class PMA_Types
     /**
      * Returns array of all functions available.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getAllFunctions()
@@ -248,7 +248,7 @@ class PMA_Types
     /**
      * Returns array of all attributes available.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getAttributes()
@@ -259,7 +259,7 @@ class PMA_Types
     /**
      * Returns array of all column types available.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getColumns()
@@ -314,7 +314,7 @@ class PMA_Types_MySQL extends PMA_Types
      */
     public function getTypeDescription($type)
     {
-        $type = strtoupper($type);
+        $type = /*overload*/mb_strtoupper($type);
         switch ($type) {
         case 'TINYINT':
             return __('A 1-byte integer, signed range is -128 to 127, unsigned range is 0 to 255');
@@ -409,7 +409,7 @@ class PMA_Types_MySQL extends PMA_Types
      */
     public function getTypeClass($type)
     {
-        $type = strtoupper($type);
+        $type = /*overload*/mb_strtoupper($type);
         switch ($type) {
         case 'TINYINT':
         case 'SMALLINT':
@@ -467,7 +467,7 @@ class PMA_Types_MySQL extends PMA_Types
      *
      * @param string $class The class to get function list.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getFunctionsClass($class)
@@ -583,13 +583,6 @@ class PMA_Types_MySQL extends PMA_Types
                 'WEEKOFYEAR',
                 'YEARWEEK',
             );
-            // remove functions that are unavailable on current server
-            if (PMA_MYSQL_INT_VERSION < 50500) {
-                $ret = array_diff($ret, array('TO_SECONDS'));
-            }
-            if (PMA_MYSQL_INT_VERSION < 50120) {
-                $ret = array_diff($ret, array('UUID_SHORT'));
-            }
             return $ret;
 
         case 'SPATIAL':
@@ -620,7 +613,7 @@ class PMA_Types_MySQL extends PMA_Types
     /**
      * Returns array of all attributes available.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getAttributes()
@@ -640,7 +633,7 @@ class PMA_Types_MySQL extends PMA_Types
      * VARCHAR, TINYINT, TEXT and DATE are listed first, based on
      * estimated popularity.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getColumns()
@@ -664,7 +657,6 @@ class PMA_Types_MySQL extends PMA_Types
             'SERIAL',
         );
 
-
         // Date/Time
         $ret[_pgettext('date and time types', 'Date and time')] = array(
             'DATE',
@@ -770,7 +762,7 @@ class PMA_Types_Drizzle extends PMA_Types
      */
     public function getTypeDescription($type)
     {
-        $type = strtoupper($type);
+        $type = /*overload*/mb_strtoupper($type);
         switch ($type) {
         case 'INTEGER':
             return __('A 4-byte integer, range is -2,147,483,648 to 2,147,483,647');
@@ -819,7 +811,7 @@ class PMA_Types_Drizzle extends PMA_Types
      */
     public function getTypeClass($type)
     {
-        $type = strtoupper($type);
+        $type = /*overload*/mb_strtoupper($type);
         switch ($type) {
         case 'INTEGER':
         case 'BIGINT':
@@ -853,7 +845,7 @@ class PMA_Types_Drizzle extends PMA_Types
      *
      * @param string $class The class to get function list.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getFunctionsClass($class)
@@ -987,7 +979,7 @@ class PMA_Types_Drizzle extends PMA_Types
     /**
      * Returns array of all attributes available.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getAttributes()
@@ -1001,7 +993,7 @@ class PMA_Types_Drizzle extends PMA_Types
     /**
      * Returns array of all column types available.
      *
-     * @return array
+     * @return string[]
      *
      */
     public function getColumns()
