@@ -28,6 +28,18 @@ if (! empty($_REQUEST['target'])) {
  */
 require './libraries/plugins/auth/swekey/swekey.auth.lib.php';
 
+/**
+ * phpseclib
+ */
+if (! function_exists('openssl_encrypt')
+    || ! function_exists('openssl_decrypt')
+    || ! function_exists('openssl_random_pseudo_bytes')
+    || PHP_VERSION_ID < 50304
+) {
+    require PHPSECLIB_INC_DIR . '/Crypt/AES.php';
+    require PHPSECLIB_INC_DIR . '/Crypt/Random.php';
+}
+
 /**
  * Handles the cookie authentication method
  *
@@ -36,9 +48,9 @@ require './libraries/plugins/auth/swekey/swekey.auth.lib.php';
 class AuthenticationCookie extends AuthenticationPlugin
 {
     /**
-     * IV for Blowfish.
+     * IV for encryption
      */
-    private $_blowfish_iv = null;
+    private $_cookie_iv = null;
 
     /**
      * Displays authentication form
@@ -56,11 +68,8 @@ class AuthenticationCookie extends AuthenticationPlugin
         $response = PMA_Response::getInstance();
         if ($response->isAjax()) {
             $response->isSuccess(false);
-
-            $response->addJSON(
-                'redirect_flag',
-                '1'
-            );
+            // redirect_flag redirects to the login page
+            $response->addJSON('redirect_flag', '1');
             if (defined('TESTSUITE')) {
                 return true;
             } else {
@@ -99,7 +108,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         $header = $response->getHeader();
         $header->setBodyId('loginform');
         $header->setTitle('phpMyAdmin');
-        $header->disableMenu();
+        $header->disableMenuAndConsole();
         $header->disableWarnings();
 
         if (file_exists(CUSTOM_HEADER_FILE)) {
@@ -108,7 +117,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         echo '
     <div class="container">
     <a href="';
-        echo PMA_linkURL('http://www.phpmyadmin.net/');
+        echo PMA_linkURL('https://www.phpmyadmin.net/');
         echo '" target="_blank" class="logo">';
         $logo_image = $GLOBALS['pmaThemeImage'] . 'logo_right.png';
         if (@file_exists($logo_image)) {
@@ -224,37 +233,10 @@ class AuthenticationCookie extends AuthenticationPlugin
             && !$skip
         ) {
             // If enabled show captcha to the user on the login screen.
-            echo '<script type="text/javascript">
-                    var RecaptchaOptions = {
-                        theme : "white"
-                    };
-                 </script>
-                 <script type="text/javascript"
-                    src="https://www.google.com/recaptcha/api/challenge?'
-                    . 'k=' . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '&amp;'
-                    . 'hl=' . $GLOBALS['lang'] . '">
-                 </script>
-                 <noscript>
-                    <iframe src="https://www.google.com/recaptcha/api/noscript?k='
-                . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '"
-                        height="300" width="500" frameborder="0"></iframe><br>
-                    <textarea name="recaptcha_challenge_field" rows="3" cols="40">
-                    </textarea>
-                    <input type="hidden" name="recaptcha_response_field"
-                        value="manual_challenge">
-                 </noscript>
-                 <script type="text/javascript">
-                    $(function() {
-                        $("#recaptcha_reload_btn," +
-                          "#recaptcha_switch_audio_btn," +
-                          "#recaptcha_switch_img_btn," +
-                          "#recaptcha_whatsthis_btn," +
-                          "#recaptcha_audio_play_again")
-                        .live("mouseover", function() {
-                            $(this).addClass("disableAjax");
-                        });
-                    });
-                 </script>';
+            echo '<script src="https://www.google.com/recaptcha/api.js?hl='
+                . $GLOBALS['lang'] . '" async defer></script>';
+            echo '<div class="g-recaptcha" data-sitekey="'
+                . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '"></div>';
         }
 
         echo '</fieldset>
@@ -281,7 +263,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         // END Swekey Integration
 
         if ($GLOBALS['error_handler']->hasDisplayErrors()) {
-            echo '<div>';
+            echo '<div id="pma_errors">';
             $GLOBALS['error_handler']->dispErrors();
             echo '</div>';
         }
@@ -308,11 +290,7 @@ class AuthenticationCookie extends AuthenticationPlugin
      *
      * it returns true if all seems ok which usually leads to auth_set_user()
      *
-     * it directly switches to authFails() if user inactivity timout is reached
-     *
-     * @todo    AllowArbitraryServer on does not imply that the user wants an
-     *          arbitrary server, or? so we should also check if this is filled
-     *          and not only if allowed
+     * it directly switches to authFails() if user inactivity timeout is reached
      *
      * @return boolean   whether we get authentication settings or not
      */
@@ -345,54 +323,6 @@ class AuthenticationCookie extends AuthenticationPlugin
             return false;
         }
 
-        // We already have one correct captcha.
-        $skip = false;
-        if (  isset($_SESSION['last_valid_captcha'])
-            && $_SESSION['last_valid_captcha']
-        ) {
-            $skip = true;
-        }
-
-        // Verify Captcha if it is required.
-        if (  !empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
-            && !empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
-            && !$skip
-        ) {
-            if (  !empty($_POST["recaptcha_challenge_field"])
-                && !empty($_POST["recaptcha_response_field"])
-            ) {
-                include_once 'libraries/plugins/auth/recaptchalib.php';
-
-                // Use private key to verify captcha status.
-                $resp = recaptcha_check_answer(
-                    $GLOBALS['cfg']['CaptchaLoginPrivateKey'],
-                    $_SERVER["REMOTE_ADDR"],
-                    $_POST["recaptcha_challenge_field"],
-                    $_POST["recaptcha_response_field"]
-                );
-
-                // Check if the captcha entered is valid, if not stop the login.
-                if ( !$resp->is_valid ) {
-                    $conn_error = __('Entered captcha is wrong, try again!');
-                    $_SESSION['last_valid_captcha'] = false;
-                    return false;
-                } else {
-                    $_SESSION['last_valid_captcha'] = true;
-                }
-            } elseif (! empty($_POST["recaptcha_challenge_field"])
-                && empty($_POST["recaptcha_response_field"])
-            ) {
-                $conn_error = __('Please enter correct captcha!');
-                return false;
-            } else {
-                if (! isset($_SESSION['last_valid_captcha'])
-                    || ! $_SESSION['last_valid_captcha']
-                ) {
-                    return false;
-                }
-            }
-        }
-
         if (! empty($_REQUEST['old_usr'])) {
             // The user wants to be logged out
             // -> delete his choices that were stored in session
@@ -424,6 +354,51 @@ class AuthenticationCookie extends AuthenticationPlugin
         }
 
         if (! empty($_REQUEST['pma_username'])) {
+
+            // We already have one correct captcha.
+            $skip = false;
+            if (isset($_SESSION['last_valid_captcha'])
+                && $_SESSION['last_valid_captcha']
+            ) {
+                $skip = true;
+            }
+
+            // Verify Captcha if it is required.
+            if (! empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
+                && ! empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
+                && ! $skip
+            ) {
+                if (! empty($_POST["g-recaptcha-response"])) {
+
+                    include_once 'libraries/plugins/auth/recaptcha/recaptchalib.php';
+                    $reCaptcha = new ReCaptcha(
+                        $GLOBALS['cfg']['CaptchaLoginPrivateKey']
+                    );
+
+                    // verify captcha status.
+                    $resp = $reCaptcha->verifyResponse(
+                        $_SERVER["REMOTE_ADDR"],
+                        $_POST["g-recaptcha-response"]
+                    );
+
+                    // Check if the captcha entered is valid, if not stop the login.
+                    if ($resp == null || ! $resp->success) {
+                        $conn_error = __('Entered captcha is wrong, try again!');
+                        $_SESSION['last_valid_captcha'] = false;
+                        return false;
+                    } else {
+                        $_SESSION['last_valid_captcha'] = true;
+                    }
+                } else {
+                    if (! isset($_SESSION['last_valid_captcha'])
+                        || ! $_SESSION['last_valid_captcha']
+                    ) {
+                        $conn_error = __('Please enter correct captcha!');
+                        return false;
+                    }
+                }
+            }
+
             // The user just logged in
             $GLOBALS['PHP_AUTH_USER'] = $_REQUEST['pma_username'];
             $GLOBALS['PHP_AUTH_PW']   = empty($_REQUEST['pma_password'])
@@ -432,6 +407,24 @@ class AuthenticationCookie extends AuthenticationPlugin
             if ($GLOBALS['cfg']['AllowArbitraryServer']
                 && isset($_REQUEST['pma_servername'])
             ) {
+                if ($GLOBALS['cfg']['ArbitraryServerRegexp']) {
+                    $parts = explode(' ', $_REQUEST['pma_servername']);
+                    if (count($parts) == 2) {
+                        $tmp_host = $parts[0];
+                    } else {
+                        $tmp_host = $_REQUEST['pma_servername'];
+                    }
+
+                    $match = preg_match(
+                        $GLOBALS['cfg']['ArbitraryServerRegexp'], $tmp_host
+                    );
+                    if (! $match) {
+                        $conn_error = __(
+                            'You are not allowed to log in to this MySQL server!'
+                        );
+                        return false;
+                    }
+                }
                 $GLOBALS['pma_auth_server'] = $_REQUEST['pma_servername'];
             }
             return true;
@@ -450,14 +443,14 @@ class AuthenticationCookie extends AuthenticationPlugin
 
         // check cookies
         if (empty($_COOKIE['pmaUser-' . $GLOBALS['server']])
-            || empty($_COOKIE['pma_mcrypt_iv'])
+            || empty($_COOKIE['pma_iv-' . $GLOBALS['server']])
         ) {
             return false;
         }
 
-        $GLOBALS['PHP_AUTH_USER'] = $this->blowfishDecrypt(
+        $GLOBALS['PHP_AUTH_USER'] = $this->cookieDecrypt(
             $_COOKIE['pmaUser-' . $GLOBALS['server']],
-            $this->_getBlowfishSecret()
+            $this->_getEncryptionSecret()
         );
 
         // user was never logged in since session start
@@ -469,11 +462,12 @@ class AuthenticationCookie extends AuthenticationPlugin
         $last_access_time = time() - $GLOBALS['cfg']['LoginCookieValidity'];
         if ($_SESSION['last_access_time'] < $last_access_time
         ) {
-            PMA_Util::cacheUnset('is_create_db_priv', null);
-            PMA_Util::cacheUnset('is_process_priv', null);
-            PMA_Util::cacheUnset('is_reload_priv', null);
-            PMA_Util::cacheUnset('db_to_create', null);
-            PMA_Util::cacheUnset('dbs_where_create_table_allowed', null);
+            PMA_Util::cacheUnset('is_create_db_priv');
+            PMA_Util::cacheUnset('is_process_priv');
+            PMA_Util::cacheUnset('is_reload_priv');
+            PMA_Util::cacheUnset('db_to_create');
+            PMA_Util::cacheUnset('dbs_where_create_table_allowed');
+            PMA_Util::cacheUnset('dbs_to_test');
             $GLOBALS['no_activity'] = true;
             $this->authFails();
             if (! defined('TESTSUITE')) {
@@ -488,9 +482,9 @@ class AuthenticationCookie extends AuthenticationPlugin
             return false;
         }
 
-        $GLOBALS['PHP_AUTH_PW'] = $this->blowfishDecrypt(
+        $GLOBALS['PHP_AUTH_PW'] = $this->cookieDecrypt(
             $_COOKIE['pmaPass-' . $GLOBALS['server']],
-            $this->_getBlowfishSecret()
+            $this->_getSessionEncryptionSecret()
         );
 
         if ($GLOBALS['PHP_AUTH_PW'] == "\xff(blank)") {
@@ -555,32 +549,30 @@ class AuthenticationCookie extends AuthenticationPlugin
         // Avoid showing the password in phpinfo()'s output
         unset($GLOBALS['PHP_AUTH_PW']);
         unset($_SERVER['PHP_AUTH_PW']);
+        if (isset($_REQUEST['access_time'])) {
+            $_SESSION['last_access_time'] = time() - $_REQUEST['access_time'];
+        } else {
+            $_SESSION['last_access_time'] = time();
+        }
+    }
 
-        $_SESSION['last_access_time'] = time();
+    /**
+     * Stores user credentials after successful login.
+     *
+     * @return void|bool
+     */
+    public function storeUserCredentials()
+    {
+        global $cfg;
 
-        $this->createBlowfishIV();
+        $this->createIV();
 
         // Name and password cookies need to be refreshed each time
         // Duration = one month for username
-        $GLOBALS['PMA_Config']->setCookie(
-            'pmaUser-' . $GLOBALS['server'],
-            $this->blowfishEncrypt(
-                $cfg['Server']['user'],
-                $this->_getBlowfishSecret()
-            )
-        );
+        $this->storeUsernameCookie($cfg['Server']['user']);
 
         // Duration = as configured
-        $GLOBALS['PMA_Config']->setCookie(
-            'pmaPass-' . $GLOBALS['server'],
-            $this->blowfishEncrypt(
-                ! empty($cfg['Server']['password'])
-                ? $cfg['Server']['password'] : "\xff(blank)",
-                $this->_getBlowfishSecret()
-            ),
-            null,
-            $GLOBALS['cfg']['LoginCookieStore']
-        );
+        $this->storePasswordCookie($cfg['Server']['password']);
 
         // Set server cookies if required (once per session) and, in this case,
         // force reload to ensure the client accepts cookies
@@ -605,10 +597,10 @@ class AuthenticationCookie extends AuthenticationPlugin
 
             // any parameters to pass?
             $url_params = array();
-            if (strlen($GLOBALS['db'])) {
+            if (/*overload*/mb_strlen($GLOBALS['db'])) {
                 $url_params['db'] = $GLOBALS['db'];
             }
-            if (strlen($GLOBALS['table'])) {
+            if (/*overload*/mb_strlen($GLOBALS['table'])) {
                 $url_params['table'] = $GLOBALS['table'];
             }
             // any target to pass?
@@ -626,7 +618,7 @@ class AuthenticationCookie extends AuthenticationPlugin
             PMA_Response::getInstance()->disable();
 
             PMA_sendHeaderLocation(
-                $redirect_url . PMA_URL_getCommon($url_params, '&'),
+                $redirect_url . PMA_URL_getCommon($url_params, 'text'),
                 true
             );
             if (! defined('TESTSUITE')) {
@@ -637,7 +629,47 @@ class AuthenticationCookie extends AuthenticationPlugin
         } // end if
 
         return true;
+    }
 
+    /**
+     * Stores username in a cookie.
+     *
+     * @param string $username User name
+     *
+     * @return void
+     */
+    public function storeUsernameCookie($username)
+    {
+        // Name and password cookies need to be refreshed each time
+        // Duration = one month for username
+        $GLOBALS['PMA_Config']->setCookie(
+            'pmaUser-' . $GLOBALS['server'],
+            $this->cookieEncrypt(
+                $username,
+                $this->_getEncryptionSecret()
+            )
+        );
+    }
+
+    /**
+     * Stores password in a cookie.
+     *
+     * @param string $password Password
+     *
+     * @return void
+     */
+    public function storePasswordCookie($password)
+    {
+        // Duration = as configured
+        $GLOBALS['PMA_Config']->setCookie(
+            'pmaPass-' . $GLOBALS['server'],
+            $this->cookieEncrypt(
+                ! empty($password) ? $password : "\xff(blank)",
+                $this->_getSessionEncryptionSecret()
+            ),
+            null,
+            $GLOBALS['cfg']['LoginCookieStore']
+        );
     }
 
     /**
@@ -647,7 +679,7 @@ class AuthenticationCookie extends AuthenticationPlugin
      * and the login form
      *
      * this function MUST exit/quit the application,
-     * currently doen by call to auth()
+     * currently done by call to auth()
      *
      * @return void
      */
@@ -658,24 +690,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         // Deletes password cookie and displays the login form
         $GLOBALS['PMA_Config']->removeCookie('pmaPass-' . $GLOBALS['server']);
 
-        if (! empty($GLOBALS['login_without_password_is_forbidden'])) {
-            $conn_error = __(
-                'Login without a password is forbidden by configuration'
-                . ' (see AllowNoPassword)'
-            );
-        } elseif (! empty($GLOBALS['allowDeny_forbidden'])) {
-            $conn_error = __('Access denied!');
-        } elseif (! empty($GLOBALS['no_activity'])) {
-            $conn_error = sprintf(
-                __('No activity within %s seconds; please log in again.'),
-                $GLOBALS['cfg']['LoginCookieValidity']
-            );
-        } elseif ($GLOBALS['dbi']->getError()) {
-            $conn_error = '#' . $GLOBALS['errno'] . ' '
-                . __('Cannot log in to the MySQL server');
-        } else {
-            $conn_error = __('Cannot log in to the MySQL server');
-        }
+        $conn_error = $this->getErrorMessage();
 
         // needed for PHP-CGI (not need for FastCGI or mod-php)
         header('Cache-Control: no-store, no-cache, must-revalidate');
@@ -689,14 +704,10 @@ class AuthenticationCookie extends AuthenticationPlugin
      *
      * @return string
      */
-    private function _getBlowfishSecret()
+    private function _getEncryptionSecret()
     {
         if (empty($GLOBALS['cfg']['blowfish_secret'])) {
-            if (empty($_SESSION['auto_blowfish_secret'])) {
-                // this returns 23 characters
-                $_SESSION['auto_blowfish_secret'] = uniqid('', true);
-            }
-            return $_SESSION['auto_blowfish_secret'];
+            return $this->_getSessionEncryptionSecret();
         } else {
             // apply md5() to work around too long secrets (returns 32 characters)
             return md5($GLOBALS['cfg']['blowfish_secret']);
@@ -704,72 +715,112 @@ class AuthenticationCookie extends AuthenticationPlugin
     }
 
     /**
-     * Encryption using blowfish algorithm (mcrypt)
-     * or phpseclib's AES if mcrypt not available
+     * Returns blowfish secret or generates one if needed.
+     *
+     * @return string
+     */
+    private function _getSessionEncryptionSecret()
+    {
+        if (empty($_SESSION['encryption_key'])) {
+            if ($this->_useOpenSSL()) {
+                $_SESSION['encryption_key'] = openssl_random_pseudo_bytes(256);
+            } else {
+                $_SESSION['encryption_key'] = crypt_random_string(256);
+            }
+        }
+        return $_SESSION['encryption_key'];
+    }
+
+    /**
+     * Checks whether we should use openssl for encryption.
+     *
+     * @return boolean
+     */
+    private function _useOpenSSL()
+    {
+        return (
+            function_exists('openssl_encrypt')
+            && function_exists('openssl_decrypt')
+            && function_exists('openssl_random_pseudo_bytes')
+            && PHP_VERSION_ID >= 50304
+        );
+    }
+
+    /**
+     * Encryption using openssl's AES or phpseclib's AES
+     * (phpseclib uses mcrypt when it is available)
      *
      * @param string $data   original data
      * @param string $secret the secret
      *
      * @return string the encrypted result
      */
-    public function blowfishEncrypt($data, $secret)
+    public function cookieEncrypt($data, $secret)
     {
-        if (! function_exists('mcrypt_encrypt')) {
-            /**
-             * This library uses mcrypt when available, so
-             * we could always call it instead of having an
-             * if/then/else logic, however the include_once
-             * call is costly
-             */
-            include_once PHPSECLIB_INC_DIR . '/Crypt/AES.php';
-            $cipher = new Crypt_AES(CRYPT_AES_MODE_ECB);
+        if ($this->_useOpenSSL()) {
+            return openssl_encrypt(
+                $data,
+                'AES-128-CBC',
+                $secret,
+                0,
+                $this->_cookie_iv
+            );
+        } else {
+            $cipher = new Crypt_AES(CRYPT_AES_MODE_CBC);
+            $cipher->setIV($this->_cookie_iv);
             $cipher->setKey($secret);
             return base64_encode($cipher->encrypt($data));
-        } else {
-            return base64_encode(
-                mcrypt_encrypt(
-                    MCRYPT_BLOWFISH,
-                    $secret,
-                    $data,
-                    MCRYPT_MODE_CBC,
-                    $this->_blowfish_iv
-                )
-            );
         }
     }
 
     /**
-     * Decryption using blowfish algorithm (mcrypt)
-     * or phpseclib's AES if mcrypt not available
+     * Decryption using openssl's AES or phpseclib's AES
+     * (phpseclib uses mcrypt when it is available)
      *
      * @param string $encdata encrypted data
      * @param string $secret  the secret
      *
      * @return string original data
      */
-    public function blowfishDecrypt($encdata, $secret)
+    public function cookieDecrypt($encdata, $secret)
     {
-        if (is_null($this->_blowfish_iv)) {
-            $this->_blowfish_iv = base64_decode($_COOKIE['pma_mcrypt_iv'], true);
+        if (is_null($this->_cookie_iv)) {
+            $this->_cookie_iv = base64_decode($_COOKIE['pma_iv-' . $GLOBALS['server']], true);
         }
-        if (! function_exists('mcrypt_encrypt')) {
-            include_once PHPSECLIB_INC_DIR . '/Crypt/AES.php';
-            $cipher = new Crypt_AES(CRYPT_AES_MODE_ECB);
+        if (strlen($this->_cookie_iv) < $this->getIVSize()) {
+                $this->createIV();
+        }
+
+        if ($this->_useOpenSSL()) {
+            return openssl_decrypt(
+                $encdata,
+                'AES-128-CBC',
+                $secret,
+                0,
+                $this->_cookie_iv
+            );
+        } else {
+            $cipher = new Crypt_AES(CRYPT_AES_MODE_CBC);
+            $cipher->setIV($this->_cookie_iv);
             $cipher->setKey($secret);
             return $cipher->decrypt(base64_decode($encdata));
-        } else {
-            $data = base64_decode($encdata);
-            $decrypted = mcrypt_decrypt(
-                MCRYPT_BLOWFISH,
-                $secret,
-                $data,
-                MCRYPT_MODE_CBC,
-                $this->_blowfish_iv
-            );
-            return trim($decrypted);
         }
     }
 
+    /**
+     * Returns size of IV for encryption.
+     *
+     * @return int
+     */
+    public function getIVSize()
+    {
+        if ($this->_useOpenSSL()) {
+            return openssl_cipher_iv_length('AES-128-CBC');
+        }
+        $cipher = new Crypt_AES(CRYPT_AES_MODE_CBC);
+        return $cipher->block_size;
+    }
+
     /**
      * Initialization
      * Store the initialization vector because it will be needed for
@@ -778,52 +829,44 @@ class AuthenticationCookie extends AuthenticationPlugin
      *
      * @return void
      */
-    public function createBlowfishIV()
+    public function createIV()
     {
-        if (function_exists('mcrypt_encrypt')) {
-            $td = mcrypt_module_open(MCRYPT_BLOWFISH, '', MCRYPT_MODE_CBC, '');
-            if ($td === false) {
-                PMA_fatalError(__('Failed to use Blowfish from mcrypt!'));
-            }
-            $this->_blowfish_iv = mcrypt_create_iv(
-                mcrypt_enc_get_iv_size($td),
-                MCRYPT_DEV_URANDOM
+        if ($this->_useOpenSSL()) {
+            $this->_cookie_iv = openssl_random_pseudo_bytes(
+                $this->getIVSize()
             );
         } else {
-            /*
-             * We don't use this value without mcrypt, but let's set it
-             * so that we don't have to check conditionally for it.
-             */
-            $this->_blowfish_iv = 'dummy';
+            $this->_cookie_iv = crypt_random_string(
+                $this->getIVSize()
+            );
         }
         $GLOBALS['PMA_Config']->setCookie(
-            'pma_mcrypt_iv',
-            base64_encode($this->_blowfish_iv)
+            'pma_iv-' . $GLOBALS['server'],
+            base64_encode($this->_cookie_iv)
         );
     }
 
     /**
-     * Sets Blowfis IV to use
+     * Sets encryption IV to use
      *
      * @param string $vector The IV
      *
      * @return void
      */
-    public function setBlowfishIv($vector)
+    public function setIV($vector)
     {
-        $this->_blowfish_iv = $vector;
+        $this->_cookie_iv = $vector;
     }
 
     /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
+     * Callback when user changes password.
      *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
+     * @param string $password New password to set
      *
      * @return void
      */
-    public function update (SplSubject $subject)
+    public function handlePasswordChange($password)
     {
+        $this->storePasswordCookie($password);
     }
 }
