@@ -70,19 +70,6 @@ class ExportYaml extends ExportPlugin
         $this->properties = $exportPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Outputs export header
      *
@@ -110,11 +97,12 @@ class ExportYaml extends ExportPlugin
     /**
      * Outputs database header
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBHeader ($db)
+    public function exportDBHeader ($db, $db_alias = '')
     {
         return true;
     }
@@ -134,11 +122,12 @@ class ExportYaml extends ExportPlugin
     /**
      * Outputs CREATE DATABASE statement
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBCreate($db)
+    public function exportDBCreate($db, $db_alias = '')
     {
         return true;
     }
@@ -151,11 +140,16 @@ class ExportYaml extends ExportPlugin
      * @param string $crlf      the end of line sequence
      * @param string $error_url the url to go back in case of error
      * @param string $sql_query SQL query for obtaining data
+     * @param array  $aliases   Aliases of db/table/columns
      *
      * @return bool Whether it succeeded
      */
-    public function exportData($db, $table, $crlf, $error_url, $sql_query)
-    {
+    public function exportData(
+        $db, $table, $crlf, $error_url, $sql_query, $aliases = array()
+    ) {
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
         $result = $GLOBALS['dbi']->query(
             $sql_query, null, PMA_DatabaseInterface::QUERY_UNBUFFERED
         );
@@ -163,9 +157,12 @@ class ExportYaml extends ExportPlugin
         $columns_cnt = $GLOBALS['dbi']->numFields($result);
         $columns = array();
         for ($i = 0; $i < $columns_cnt; $i++) {
-            $columns[$i] = stripslashes($GLOBALS['dbi']->fieldName($result, $i));
+            $col_as = $GLOBALS['dbi']->fieldName($result, $i);
+            if (!empty($aliases[$db]['tables'][$table]['columns'][$col_as])) {
+                $col_as = $aliases[$db]['tables'][$table]['columns'][$col_as];
+            }
+            $columns[$i] = stripslashes($col_as);
         }
-        unset($i);
 
         $buffer = '';
         $record_cnt = 0;
@@ -174,7 +171,7 @@ class ExportYaml extends ExportPlugin
 
             // Output table name as comment if this is the first record of the table
             if ($record_cnt == 1) {
-                $buffer = '# ' . $db . '.' . $table . $crlf;
+                $buffer = '# ' . $db_alias . '.' . $table_alias . $crlf;
                 $buffer .= '-' . $crlf;
             } else {
                 $buffer = '-' . $crlf;
@@ -185,15 +182,13 @@ class ExportYaml extends ExportPlugin
                     continue;
                 }
 
-                $column = $columns[$i];
-
                 if (is_null($record[$i])) {
-                    $buffer .= '  ' . $column . ': null' . $crlf;
+                    $buffer .= '  ' . $columns[$i] . ': null' . $crlf;
                     continue;
                 }
 
                 if (is_numeric($record[$i])) {
-                    $buffer .= '  ' . $column . ': '  . $record[$i] . $crlf;
+                    $buffer .= '  ' . $columns[$i] . ': '  . $record[$i] . $crlf;
                     continue;
                 }
 
@@ -202,7 +197,7 @@ class ExportYaml extends ExportPlugin
                     array('\\\\', '\"', '\n', '\r'),
                     $record[$i]
                 );
-                $buffer .= '  ' . $column . ': "' . $record[$i] . '"' . $crlf;
+                $buffer .= '  ' . $columns[$i] . ': "' . $record[$i] . '"' . $crlf;
             }
 
             if (! PMA_exportOutputHandler($buffer)) {
