@@ -59,19 +59,6 @@ class ImportShp extends ImportPlugin
         $this->properties = $importPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Handles the whole import logic
      *
@@ -120,8 +107,10 @@ class ImportShp extends ImportPlugin
                         $temp_dbf_file = true;
                         // Replace the .dbf with .*, as required
                         // by the bsShapeFiles library.
-                        $file_name = substr(
-                            $dbf_file_path, 0, strlen($dbf_file_path) - 4
+                        $file_name = /*overload*/mb_substr(
+                            $dbf_file_path,
+                            0,
+                            /*overload*/mb_strlen($dbf_file_path) - 4
                         ) . '.*';
                         $shp->FileName = $file_name;
                     }
@@ -134,8 +123,11 @@ class ImportShp extends ImportPlugin
                 // to load extra data.
                 // Replace the .shp with .*,
                 // so the bsShapeFiles library correctly locates .dbf file.
-                $file_name = substr($import_file, 0, strlen($import_file) - 4)
-                    . '.*';
+                $file_name = /*overload*/mb_substr(
+                    $import_file,
+                    0,
+                    /*overload*/mb_strlen($import_file) - 4
+                ) . '.*';
                 $shp->FileName = $file_name;
             }
         }
@@ -268,7 +260,7 @@ class ImportShp extends ImportPlugin
         }
 
         // Set table name based on the number of tables
-        if (strlen($db)) {
+        if (/*overload*/mb_strlen($db)) {
             $result = $GLOBALS['dbi']->fetchResult('SHOW TABLES');
             $table_name = 'TABLE ' . (count($result) + 1);
         } else {
@@ -285,7 +277,7 @@ class ImportShp extends ImportPlugin
         $analyses[$table_no][FORMATTEDSQL][$spatial_col] = true;
 
         // Set database name to the currently selected one, if applicable
-        if (strlen($db)) {
+        if (/*overload*/mb_strlen($db)) {
             $db_name = $db;
             $options = array('create_db' => false);
         } else {
