@@ -3,7 +3,7 @@
 /**
  * Manipulation of table data like inserting, replacing and updating
  *
- * Usally called as form action from tbl_change.php to insert or update table rows
+ * Usually called as form action from tbl_change.php to insert or update table rows
  *
  * @todo 'edit_next' tends to not work as expected if used ...
  * at least there is no order by it needs the original query
@@ -21,6 +21,7 @@ require_once 'libraries/common.inc.php';
  * functions implementation for this script
  */
 require_once 'libraries/insert_edit.lib.php';
+require_once 'libraries/transformations.lib.php';
 
 // Check parameters
 PMA_Util::checkParameters(array('db', 'table', 'goto'));
@@ -125,7 +126,16 @@ $gis_from_wkb_functions = array(
 // to create an object of PMA_File class
 require_once './libraries/File.class.php';
 
+//if some posted fields need to be transformed.
+$mime_map = PMA_getMIME($GLOBALS['db'], $GLOBALS['table']);
+if ($mime_map === false) {
+    $mime_map = array();
+}
+
 $query_fields = array();
+$insert_errors = array();
+$row_skipped = false;
+$unsaved_values = array();
 foreach ($loop_array as $rownumber => $where_clause) {
     // skip fields to be ignored
     if (! $using_key && isset($_REQUEST['insert_ignore_' . $where_clause])) {
@@ -136,7 +146,7 @@ foreach ($loop_array as $rownumber => $where_clause) {
     $query_values = array();
 
     // Map multi-edit keys to single-level arrays, dependent on how we got the fields
-    $multi_edit_colummns
+    $multi_edit_columns
         = isset($_REQUEST['fields']['multi_edit'][$rownumber])
         ? $_REQUEST['fields']['multi_edit'][$rownumber]
         : array();
@@ -174,18 +184,19 @@ foreach ($loop_array as $rownumber => $where_clause) {
         : null;
 
     // When a select field is nullified, it's not present in $_REQUEST
-    // so initialize it; this way, the foreach($multi_edit_colummns) will process it
+    // so initialize it; this way, the foreach($multi_edit_columns) will process it
     foreach ($multi_edit_columns_name as $key => $val) {
-        if (! isset($multi_edit_colummns[$key])) {
-            $multi_edit_colummns[$key] = '';
+        if (! isset($multi_edit_columns[$key])) {
+            $multi_edit_columns[$key] = '';
         }
     }
 
     // Iterate in the order of $multi_edit_columns_name,
-    // not $multi_edit_colummns, to avoid problems
+    // not $multi_edit_columns, to avoid problems
     // when inserting multiple entries
-    foreach ($multi_edit_columns_name as $key => $colummn_name) {
-        $current_value = $multi_edit_colummns[$key];
+    $insert_fail = false;
+    foreach ($multi_edit_columns_name as $key => $column_name) {
+        $current_value = $multi_edit_columns[$key];
         // Note: $key is an md5 of the fieldname. The actual fieldname is
         // available in $multi_edit_columns_name[$key]
 
@@ -193,6 +204,42 @@ foreach ($loop_array as $rownumber => $where_clause) {
         $file_to_insert->checkTblChangeForm($key, $rownumber);
 
         $possibly_uploaded_val = $file_to_insert->getContent();
+        if ($possibly_uploaded_val !== false) {
+            $current_value = $possibly_uploaded_val;
+        }
+        // Apply Input Transformation if defined
+        if (!empty($mime_map[$column_name])
+            && !empty($mime_map[$column_name]['input_transformation'])
+        ) {
+            $filename = 'libraries/plugins/transformations/'
+                . $mime_map[$column_name]['input_transformation'];
+            if (is_file($filename)) {
+                include_once $filename;
+                $classname = PMA_getTransformationClassName(
+                    $mime_map[$column_name]['input_transformation']
+                );
+                $transformation_plugin = new $classname();
+                $transformation_options = PMA_Transformation_getOptions(
+                    $mime_map[$column_name]['input_transformation_options']
+                );
+                $current_value = $transformation_plugin->applyTransformation(
+                    $current_value, $transformation_options
+                );
+                // check if transformation was successful or not
+                // and accordingly set error messages & insert_fail
+                if (method_exists($transformation_plugin, 'isSuccess')
+                    && !$transformation_plugin->isSuccess()
+                ) {
+                    $insert_fail = true;
+                    $row_skipped = true;
+                    $insert_errors[] = sprintf(
+                        __('Row: %1$s, Column: %2$s, Error: %3$s'),
+                        $rownumber, $column_name,
+                        $transformation_plugin->getError()
+                    );
+                }
+            }
+        }
 
         if ($file_to_insert->isError()) {
             $message .= $file_to_insert->getError();
@@ -209,7 +256,7 @@ foreach ($loop_array as $rownumber => $where_clause) {
         );
 
         $current_value_as_an_array = PMA_getCurrentValueAsAnArrayForMultipleEdit(
-            $multi_edit_colummns, $multi_edit_columns_name, $multi_edit_funcs,
+            $multi_edit_funcs,
             $multi_edit_salt, $gis_from_text_functions, $current_value,
             $gis_from_wkb_functions, $func_optional_param, $func_no_param, $key
         );
@@ -221,9 +268,17 @@ foreach ($loop_array as $rownumber => $where_clause) {
                 $query_values, $query_fields, $current_value_as_an_array,
                 $value_sets, $key, $multi_edit_columns_null_prev
             );
+        if (isset($multi_edit_columns_null[$key])) {
+            $multi_edit_columns[$key] = null;
+        }
     } //end of foreach
 
-    if (count($query_values) > 0) {
+    // temporarily store rows not inserted
+    // so that they can be populated again.
+    if ($insert_fail) {
+        $unsaved_values[$rownumber] = $multi_edit_columns;
+    }
+    if (!$insert_fail && count($query_values) > 0) {
         if ($is_insert) {
             $value_sets[] = implode(', ', $query_values);
         } else {
@@ -239,12 +294,13 @@ foreach ($loop_array as $rownumber => $where_clause) {
 unset($multi_edit_columns_name, $multi_edit_columns_prev, $multi_edit_funcs,
     $multi_edit_columns_type, $multi_edit_columns_null, $func_no_param,
     $multi_edit_auto_increment, $current_value_as_an_array, $key, $current_value,
-    $loop_array, $where_clause, $using_key,  $multi_edit_columns_null_prev);
+    $loop_array, $where_clause, $using_key,  $multi_edit_columns_null_prev,
+    $insert_fail);
 
 // Builds the sql query
 if ($is_insert && count($value_sets) > 0) {
     $query = PMA_buildSqlQuery($is_insertignore, $query_fields, $value_sets);
-} elseif (empty($query)) {
+} elseif (empty($query) && ! isset($_REQUEST['preview_sql']) && !$row_skipped) {
     // No change -> move back to the calling script
     //
     // Note: logic passes here for inline edit
@@ -253,7 +309,12 @@ if ($is_insert && count($value_sets) > 0) {
     include '' . PMA_securePath($goto_include);
     exit;
 }
-unset($multi_edit_colummns, $is_insertignore);
+unset($multi_edit_columns, $is_insertignore);
+
+// If there is a request for SQL previewing.
+if (isset($_REQUEST['preview_sql'])) {
+    PMA_previewSQL($query);
+}
 
 /**
  * Executes the sql query and get the result, then move back to the calling
@@ -263,11 +324,17 @@ list ($url_params, $total_affected_rows, $last_messages, $warning_messages,
     $error_messages, $return_to_sql_query)
         = PMA_executeSqlQuery($url_params, $query);
 
-if ($is_insert && count($value_sets) > 0) {
+if ($is_insert && (count($value_sets) > 0 || $row_skipped)) {
     $message = PMA_Message::getMessageForInsertedRows($total_affected_rows);
+    $unsaved_values = array_values($unsaved_values);
 } else {
     $message = PMA_Message::getMessageForAffectedRows($total_affected_rows);
 }
+if ($row_skipped) {
+    $goto_include = 'tbl_change.php';
+    $message->addMessages($insert_errors, '<br />');
+    $message->isError(true);
+}
 
 $message->addMessages($last_messages, '<br />');
 
@@ -281,7 +348,7 @@ if (! empty($error_messages)) {
 }
 unset(
     $error_messages, $warning_messages, $total_affected_rows,
-    $last_messages, $last_message
+    $last_messages, $last_message, $row_skipped, $insert_errors
 );
 
 /**
@@ -307,11 +374,12 @@ if ($response->isAjax() && ! isset($_POST['ajax_page_request'])) {
         parse_str($_REQUEST['rel_fields_list'], $relation_fields);
 
         // loop for each relation cell
+        /** @var array $relation_fields */
         foreach ($relation_fields as $cell_index => $curr_rel_field) {
             foreach ($curr_rel_field as $relation_field => $relation_field_value) {
                 $where_comparison = "='" . $relation_field_value . "'";
                 $dispval = PMA_getDisplayValueForForeignTableColumn(
-                    $where_comparison, $relation_field_value, $map, $relation_field
+                    $where_comparison, $map, $relation_field
                 );
 
                 $extra_data['relations'][$cell_index]
@@ -325,27 +393,23 @@ if ($response->isAjax() && ! isset($_POST['ajax_page_request'])) {
     if (isset($_REQUEST['do_transformations'])
         && $_REQUEST['do_transformations'] == true
     ) {
-        include_once 'libraries/transformations.lib.php';
-        //if some posted fields need to be transformed, generate them here.
-        $mime_map = PMA_getMIME($db, $table);
-
-        if ($mime_map === false) {
-            $mime_map = array();
-        }
         $edited_values = array();
         parse_str($_REQUEST['transform_fields_list'], $edited_values);
 
         if (! isset($extra_data)) {
             $extra_data = array();
         }
+        $transformation_types = array(
+            "input_transformation",
+            "transformation"
+        );
         foreach ($mime_map as $transformation) {
-            $file = PMA_securePath($transformation['transformation']);
-            // if only an underscore in the file name, nothing to transform
-            if ($file != '_') {
-                $column_name = $transformation['column_name'];
+            $column_name = $transformation['column_name'];
+            foreach ($transformation_types as $type) {
+                $file = PMA_securePath($transformation[$type]);
                 $extra_data = PMA_transformEditedValues(
                     $db, $table, $transformation, $edited_values, $file,
-                    $column_name, $extra_data
+                    $column_name, $extra_data, $type
                 );
             }
         }   // end of loop for each $mime_map
@@ -382,6 +446,7 @@ if (! empty($return_to_sql_query)) {
 }
 
 $scripts->addFile('tbl_change.js');
+$scripts->addFile('big_ints.js');
 
 $active_page = $goto_include;
 
